# Generated by roxygen2: do not edit by hand

export(palette_pequod)
export(pequod_crew)
export(pequod_crew_dark)
export(pequod_crew_light)
export(pequod_log)
export(pequod_preview)
export(scale_color_pequod_c)
export(scale_color_pequod_d)
export(scale_colour_pequod_c)
export(scale_colour_pequod_d)
export(scale_fill_pequod_c)
export(scale_fill_pequod_d)
