% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/palettes-data.R
\docType{data}
\name{pequod_crew}
\alias{pequod_crew}
\title{Pequod crew metadata}
\format{
A list with three elements: `light`, `dark`, `roles`.
}
\usage{
pequod_crew
}
\description{
A list bundling the light and dark crew accents together with
their suggested syntax roles.
}
\keyword{datasets}
